﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using CustomSymbols.Symbols;
using Syncfusion.Windows.Diagram;

namespace CustomSymbols
{
    /// <summary>
    /// Logica di interazione per MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private static int i = 0;
        public MainWindow()
        {
            InitializeComponent();
            DiagramModelMain.Nodes.CollectionChanged += Nodes_CollectionChanged;
        }

        void Nodes_CollectionChanged(object sender, System.Collections.Specialized.NotifyCollectionChangedEventArgs e)
        {
            if (e.NewItems != null)
            {
                (e.NewItems[0] as Node).Loaded += MainWindow_Loaded;
            }
        }

        void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            (sender as Node).Name = "Node" + i;
            (sender as Node).ToolTip = (sender as BaseNode).CustomId;
            i++;
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            this.WindowState = WindowState.Maximized;
            this.InitializePalette();
        }
        private void RibbonButtonLoad_OnClick(object sender, RoutedEventArgs e)
        {
            using (var openFileDialog = new System.Windows.Forms.OpenFileDialog())
            {
                openFileDialog.Filter = "XAML File(*.xaml)|*.xaml";
                System.Windows.Forms.DialogResult result = openFileDialog.ShowDialog();

                if (result == System.Windows.Forms.DialogResult.OK || result == System.Windows.Forms.DialogResult.Yes)
                {
                    this.DiagramControlMain.Load(openFileDialog.FileName);
                }
            }
        }
        private void RibbonButtonSave_OnClick(object sender, RoutedEventArgs e)
        {
            using (var saveFileDialog = new System.Windows.Forms.SaveFileDialog())
            {
                saveFileDialog.Filter = "XAML File(*.xaml)|*.xaml";
                System.Windows.Forms.DialogResult result = saveFileDialog.ShowDialog();

                if (result == System.Windows.Forms.DialogResult.OK || result == System.Windows.Forms.DialogResult.Yes)
                {
                    this.DiagramControlMain.Save(saveFileDialog.FileName);
                }
            }
        }

        private void InitializePalette()
        {
            try
            {
                var defaultGroups = this.DiagramControlMain.SymbolPalette.SymbolGroups.ToList();
                defaultGroups.Skip(2).ToList().ForEach(rg => this.DiagramControlMain.SymbolPalette.SymbolGroups.Remove(rg));

                var defaultFilters = this.DiagramControlMain.SymbolPalette.SymbolFilters.ToList();
                defaultFilters.Skip(4).ToList().ForEach(f => this.DiagramControlMain.SymbolPalette.SymbolFilters.Remove(f));

                var filter = new SymbolPaletteFilter { Label = "Rail" };
                this.DiagramControlMain.SymbolPalette.SymbolFilters.Add(filter);

                var group = new SymbolPaletteGroup { Label = "Rail" };
                SymbolPalette.SetFilterIndexes(group, new Int32Collection(new int[] { 0, 4 }));
                this.DiagramControlMain.SymbolPalette.SymbolGroups.Add(group);

                #region RailLine Item
                var railLineItem = new RailLinePaletteItem { Name = "RailLine" };
                var railLineShape = this.FindResource("RailLineShape") as Path;
                if (railLineShape != null)
                {
                    var grid = new Grid();
                    grid.Children.Add(railLineShape);
                    railLineItem.Content = grid;
                    group.Items.Add(railLineItem);
                }
                #endregion
            

                #region Custom Symbols
                var customFilter = new SymbolPaletteFilter { Label = "Custom symbols" };
                this.DiagramControlMain.SymbolPalette.SymbolFilters.Add(customFilter);
                var customGroup = new SymbolPaletteGroup { Label = "Custom symbols" };
                SymbolPalette.SetFilterIndexes(customGroup, new Int32Collection(new int[] { 0, 5 }));
                this.DiagramControlMain.SymbolPalette.SymbolGroups.Add(customGroup);


                var acGenShape = this.FindResource("GeneratorShape") as Path;
                if (acGenShape != null)
                {
                    var genItem = new AcGenPalletteItem() { Name = "AcGen" };

                    var grid = new Grid();
                    grid.Children.Add(acGenShape);
                    AcGen node=new AcGen();
                    node.Content = grid;
                    node.IsHitTestVisible = false;
                    genItem.Content = node;
                    //genItem.Content = grid;
                    customGroup.Items.Add(genItem);
                }
                #endregion

                //#region Test

                //var testFilter = new SymbolPaletteFilter { Label = "Test" };
                //this.DiagramControlMain.SymbolPalette.SymbolFilters.Add(testFilter);
                //var testGroup = new SymbolPaletteGroup { Label = "Test" };
                //SymbolPalette.SetFilterIndexes(testGroup, new Int32Collection(new int[] { 0, 5 }));

                //this.DiagramControlMain.SymbolPalette.SymbolGroups.Add(testGroup);

                //var item = new SymbolPaletteItem { Name = "GenImage" };
                //var i = new System.Windows.Controls.Image();
                //var bitmapImage = new BitmapImage();
                //bitmapImage.BeginInit();
                //bitmapImage.UriSource = new Uri("Images/Generator.png", UriKind.RelativeOrAbsolute);
                //bitmapImage.EndInit();
                //i.Stretch = Stretch.Fill;
                //i.Source = bitmapImage;
                //item.Content = i;
                //testGroup.Items.Add(item);


                //var genShape = this.FindResource("GeneratorShape") as Path;
                //if (genShape != null)
                //{
                //    var genItem = new SymbolPaletteItem { Name = "GenPath" };

                //    var grid = new Grid();
                //    grid.Children.Add(genShape);
                //    genItem.Content = grid;
                //    testGroup.Items.Add(genItem);
                //}

                //Node n = new Node(Guid.NewGuid(), "Start");
                //n.Shape = Shapes.Ellipse;
                //n.Level = 1;
                //n.OffsetX = 150;
                //n.OffsetY = 25;
                //n.Width = 150;
                //n.Height = 75;
                //Node n1 = new Node(Guid.NewGuid(), "End");
                //n1.Shape = Shapes.RoundedRectangle;
                //n1.Level = 1;
                //n1.OffsetX = 350;
                //n1.OffsetY = 325;
                //n1.Width = 100;
                //n1.Height = 75;

                //Group g = new Group(Guid.NewGuid(), "group1");
                //g.AddChild(n);
                //g.AddChild(n1);

                //SymbolPaletteItem itemg = new SymbolPaletteItem{Name = "Group"};
                //// Group added as SymbolPaletteItem's Content
                //itemg.Content = g;
                //testGroup.Items.Add(itemg);

                //#endregion


            }
            catch (Exception exception)
            {
                System.Diagnostics.Debug.WriteLine(exception.ToString());
            }
        }
    }
}
